@@ -44,17 +44,14 @@ def noveltyslice(
 	fftsize = fftformat(fftsettings)
 	ret = subprocess.call([
 		"fluid-noveltyslice",
-		"-maxkernelsize", str(kernelsize),
-		"-maxfftsize", str(fftsize),
-		"-maxfiltersize", str(filtersize),
 		"-source", str(source),
 		"-indices", str(indices),
-		"-feature", str(feature),
+		"-algorithm", str(feature),
 		"-threshold", str(threshold),
-		"-kernelsize", str(kernelsize),
-		"-fftsettings", str(fftsettings[0]), str(fftsettings[1]), str(fftsize),
+		"-kernelsize", str(kernelsize), str(kernelsize),
+		"-fftsettings", str(fftsettings[0]), str(fftsettings[1]), str(fftsize), str(fftsize),
 		"-minslicelength", str(minslicelength),
-		"-filtersize", str(filtersize),
+		"-filtersize", str(filtersize), str(filtersize),
 		"-numchans", str(numchans),
 		"-numframes", str(numframes),
 		"-startchan", str(startchan),
@@ -225,10 +222,9 @@ def onsetslice(
 
 	ret = subprocess.call([
 		"fluid-onsetslice",
-		"-maxfftsize", str(fftsize),
 		"-source", str(source),
 		"-indices", str(indices),
-		"-fftsettings", str(fftsettings[0]), str(fftsettings[1]), str(fftsize),
+		"-fftsettings", str(fftsettings[0]), str(fftsettings[1]), str(fftsize), str(fftsize),
 		"-filtersize", str(filtersize),
 		"-framedelta", str(framedelta),
 		"-metric", str(metric),
@@ -274,7 +270,6 @@ def sines(
 
 	ret = subprocess.call([
 		"fluid-sines",
-		"-maxfftsize", str(fftsize),
 		"-source", str(source),
 		"-sines", str(sines),
 		"-residual", str(residual),
@@ -282,7 +277,7 @@ def sines(
 		"-birthhighthreshold", str(birthhighthreshold),
 		"-birthlowthreshold", str(birthlowthreshold),
 		"-detectionthreshold", str(detectionthreshold),
-		"-fftsettings", str(fftsettings[0]), str(fftsettings[1]), str(fftsize),
+		"-fftsettings", str(fftsettings[0]), str(fftsettings[1]), str(fftsize), str(fftsize),
 		"-mintracklen", str(mintracklen),
 		"-trackfreqrange", str(trackfreqrange),
 		"-trackingmethod", str(trackingmethod),
@@ -379,9 +374,9 @@ def hpss(
 		"-harmonic", str(harmonic),
 		"-percussive", str(percussive),
 		"-residual", str(residual),
-		"-fftsettings", str(fftsettings[0]), str(fftsettings[1]), str(fftsize),
-		"-harmfiltersize", str(harmfiltersize),
-		"-percfiltersize", str(percfiltersize),
+		"-fftsettings", str(fftsettings[0]), str(fftsettings[1]), str(fftsize), str(fftsize),
+		"-harmfiltersize", str(harmfiltersize), str(harmfiltersize),
+		"-percfiltersize", str(percfiltersize), str(percfiltersize),
 		"-harmthresh", str(harmthresh[0]), str(harmthresh[1]), str(harmthresh[2]), str(harmthresh[3]),
 		"-percthresh", str(percthresh[0]), str(percthresh[1]), str(percthresh[2]), str(percthresh[3]),
 		"-maskingmode", str(maskingmode),
@@ -431,10 +426,11 @@ def nmf(
 		"-activations", str(activations),
 		"-bases", str(bases),
 		"-resynth", str(resynth),
+		"-resynthmode", str(1),
 		"-actmode", str(actmode),
 		"-basesmode", str(basesmode),
 		"-components", str(components),
-		"-fftsettings", str(fftsettings[0]), str(fftsettings[1]), str(fftsize),
+		"-fftsettings", str(fftsettings[0]), str(fftsettings[1]), str(fftsize), str(fftsize),
 		"-iterations", str(iterations),
 		"-numchans", str(numchans),
 		"-numframes", str(numframes),
@@ -471,15 +467,13 @@ def mfcc(
 
 	ret = subprocess.call([
 		"fluid-mfcc",
-		"-maxnumcoeffs", str(numcoeffs),
-		"-maxfftsize", str(fftsize),
 		"-source", str(source),
 		"-features", str(features),
-		"-fftsettings", str(fftsettings[0]), str(fftsettings[1]), str(fftsize),
+		"-fftsettings", str(fftsettings[0]), str(fftsettings[1]), str(fftsize), str(fftsize),
 		"-maxfreq", str(maxfreq),
 		"-minfreq", str(minfreq),
 		"-numbands", str(numbands),
-		"-numcoeffs", str(numcoeffs),
+		"-numcoeffs", str(numcoeffs), str(numcoeffs),
 		"-numchans", str(numchans),
 		"-numframes", str(numframes),
 		"-startchan", str(startchan),
@@ -511,7 +505,7 @@ def loudness(
 		"-source", str(source),
 		"-features", str(features),
 		"-hopsize", str(hopsize),
-		"-windowsize", str(windowsize),
+		"-windowsize", str(windowsize), str(windowsize),
 		"-kweighting", str(kweighting),
 		"-truepeak", str(truepeak),
 		"-numchans", str(numchans),
@@ -546,11 +540,10 @@ def pitch(
 
 	ret = subprocess.call([
 		"fluid-pitch",
-		"-maxfftsize", str(fftsize),
 		"-source", str(source),
 		"-features", str(features),
 		"-algorithm", str(algorithm),
-		"-fftsettings", str(fftsettings[0]), str(fftsettings[1]), str(fftsize),
+		"-fftsettings", str(fftsettings[0]), str(fftsettings[1]), str(fftsize), str(fftsize),
 		"-maxfreq", str(maxfreq),
 		"-minfreq", str(minfreq),
 		"-unit", str(unit),
@@ -586,15 +579,13 @@ def melbands(
 
 	ret = subprocess.call([
 		"fluid-melbands",
-		"-maxnumbands", str(numbands),
-		'-maxfftsize', str(fftsize),	
 		"-source", str(source),
 		"-features", str(features),
-		"-fftsettings", str(fftsettings[0]), str(fftsettings[1]), str(fftsize),
+		"-fftsettings", str(fftsettings[0]), str(fftsettings[1]), str(fftsize), str(fftsize),
 		"-maxfreq", str(maxfreq),
 		"-minfreq", str(minfreq),
 		"-normalize", str(normalize),
-		"-numbands", str(numbands),
+		"-numbands", str(numbands), str(numbands),
 		"-numchans", str(numchans),
 		"-numframes", str(numframes),
 		"-startchan", str(startchan),
@@ -622,10 +613,9 @@ def spectralshape(
 
 	ret = subprocess.call([
 		"fluid-spectralshape",
-		'-maxfftsize', str(fftsize),	
 		"-source", str(source),
 		"-features", str(features),
-		"-fftsettings", str(fftsettings[0]), str(fftsettings[1]), str(fftsize),
+		"-fftsettings", str(fftsettings[0]), str(fftsettings[1]), str(fftsize), str(fftsize),
 		"-numchans", str(numchans),
 		"-numframes", str(numframes),
 		"-startchan", str(startchan),
